@@ -19,11 +19,24 @@ find_categorical <- function(newdata = NULL, model = NULL) {
         }
 
         if (!is.null(te) && is.character(te)) {
-            te <- te[grepl("^as\\.factor|^factor\\(|^as.logical\\(|^mo\\(|^strata\\(|^i\\(", te)]
+
+            # fixest::i()
+            fi <- NULL
+            idx <- grepl("^i\\(.*\\)$", te)
+            if (sum(idx) > 0) {
+                arg1 <- lapply(te[idx], function(x) hush(as.character(str2lang(x)[[2]])))
+                arg2 <- lapply(te[idx], function(x) hush(as.character(str2lang(x)[[3]])))
+                arg1 <- unlist(arg1, recursive = TRUE)
+                arg2 <- unlist(arg2, recursive = TRUE)
+                arg2 <- gsub("^i\\.", "", arg2[grepl("^i\\.", arg2)])
+                fi <- unique(c(arg1, arg2))
+            }
+
+            te <- te[grepl("^as\\.factor|^factor\\(|^as.logical\\(|^mo\\(|^strata\\(", te)]
             # some functions like strata() take arguments, but that is difficult to support
-            te <- gsub("^(^as\\.factor|^factor|^i|^as\\.logical|mo|strata)\\((.*)\\)", "\\2", te)
-            te <- te[!grepl(",", te)]
-            out_model <- te
+            te <- gsub("^(^as\\.factor|^factor|^as\\.logical|mo|strata)\\((.*)\\)", "\\2", te)
+
+            out_model <- unique(c(te[!grepl(",", te)], fi))
         }
     }
 
