@@ -16,7 +16,7 @@ get_coef.default <- function(model, ...) {
     # out <-  stats::coef(model)
 
     # more general
-    out <- insight::get_parameters(model)
+    out <- insight::get_parameters(model, component = "all")
     out <- stats::setNames(out$Estimate, out$Parameter)
     return(out)
 }
