@@ -16,6 +16,7 @@ get_contrast_data_numeric <- function(model,
         m <- mean(modeldata[[variable$name]], na.rm = TRUE)
     }
     x <- newdata[[variable$name]]
+    xmd <- modeldata[[variable$name]]
 
     make_label <- function(lab, val) {
         if (identical(lab, "custom")) return(lab)
@@ -94,14 +95,20 @@ get_contrast_data_numeric <- function(model,
         lab <- make_label(variable$label, lab)
 
     } else if (identical(variable$value, "iqr")) {
-        low <- stats::quantile(x, probs = .25, na.rm = TRUE)
-        high <- stats::quantile(x, probs = .75, na.rm = TRUE)
+        low <- stats::quantile(xmd, probs = .25, na.rm = TRUE)
+        high <- stats::quantile(xmd, probs = .75, na.rm = TRUE)
         lab <- make_label(variable$label, c("Q3", "Q1"))
 
     } else if (identical(variable$value, "minmax")) {
-        low <- min(x, na.rm = TRUE)
-        high <- max(x, na.rm = TRUE)
+        low <- min(xmd, na.rm = TRUE)
+        high <- max(xmd, na.rm = TRUE)
         lab <- make_label(variable$label, c("Max", "Min"))
+
+    } else if (isTRUE(checkmate::check_function(variable$value))) {
+        tmp <- variable$value(x)
+        low <- tmp[, 1]
+        high <- tmp[, 2]
+        lab <- "custom"
     }
 
     newdata[["eps"]] <- eps
