@@ -20,3 +20,12 @@ mod <- lm(mpg ~ hp, data = mtcars)
 cmp <- comparisons(mod, variables = list(hp = c(90, 110)))
 expect_inherits(cmp, "comparisons")
 
+
+# Issue #527
+mtcars$new_hp <- 49 * (mtcars$hp - min(mtcars$hp)) / (max(mtcars$hp) - min(mtcars$hp)) + 1
+mod <- lm(mpg ~ log(new_hp) + factor(cyl), data = mtcars)
+fdiff <- \(x) data.frame(x, x + 10)
+cmp1 <- comparisons(mod, variables = list(new_hp = fdiff))
+cmp2 <- comparisons(mod, variables = list(new_hp = 10))
+expect_equivalent(nrow(cmp1), 32)
+expect_equivalent(nrow(cmp2), 27)
\ No newline at end of file
