@@ -25,13 +25,13 @@ expect_true(all(known %in% cmp1$contrast))
 expect_equivalent(cmp1$estimate[3], cmp2$estimate[3] * 10)
 
 # informative errors
-expect_error(comparisons(mod, variables = list(gear = "blah")), pattern = "character variables")
+expect_error(comparisons(mod, variables = list(gear = "blah")), pattern = "element")
 expect_error(comparisons(mod, variables = list(hp = "pairwise"), pattern = "numeric variables"))
 
 # regression test: factor in formula and numeric check
 mod <- lm(mpg ~ factor(cyl), data = mtcars)
 expect_inherits(comparisons(mod, variables = list(cyl = "pairwise")), "comparisons")
-expect_error(comparisons(mod, variables = list(cyl = "iqr")), pattern = "factor")
+expect_error(comparisons(mod, variables = list(cyl = "iqr")), pattern = "element")
 
 
 # Binary variables
